@@ -23,7 +23,7 @@ class SMBFile:
 		self.allocation_size = None
 		self.attributes = None
 		self.file_id = None
-		self.sid = None
+		self.security_descriptor = None
 
 		#internal
 		self.__connection = None
@@ -98,7 +98,7 @@ class SMBFile:
 			return False, e
 
 	@staticmethod
-	async def delete(connection, remotepath):
+	async def delete_rempath(connection, remotepath):
 		try:
 			remfile = SMBFile.from_remotepath(connection, remotepath)
 			tree_entry, err = await connection.tree_connect(remfile.share_path)
@@ -124,8 +124,45 @@ class SMBFile:
 		except Exception as e:
 			return False, e
 
+	async def delete(self):
+		try:
+			await self.close()
+			#remfile = SMBFile.from_remotepath(connection, remotepath)
+			tree_entry, err = await self.__connection.tree_connect(self.share_path)
+			if err is not None:
+				raise err
+			tree_id = tree_entry.tree_id
+
+			desired_access = FileAccessMask.DELETE | FileAccessMask.FILE_READ_ATTRIBUTES
+			share_mode = ShareAccess.FILE_SHARE_DELETE
+			create_options = CreateOptions.FILE_NON_DIRECTORY_FILE | CreateOptions.FILE_DELETE_ON_CLOSE 
+			create_disposition = CreateDisposition.FILE_OPEN
+			file_attrs = 0
+
+			file_id, err = await self.__connection.create(
+				tree_id, 
+				self.fullpath, 
+				desired_access, 
+				share_mode, 
+				create_options, 
+				create_disposition, 
+				file_attrs, 
+				return_reply = False
+			)
+
+			if err is not None:
+				raise err
+			if file_id is not None:
+				await self.__connection.close(tree_id, file_id)
+
+			await self.__connection.tree_disconnect(tree_id)
+			return True, None
+		
+		except Exception as e:
+			return False, e
+
 	async def get_security_descriptor(self, connection):
-		if self.sid is None:
+		if self.security_descriptor is None:
 			file_id = None
 			try:
 				tree_id = self.tree_id
@@ -144,7 +181,7 @@ class SMBFile:
 				if err is not None:
 					raise err
 
-				self.sid, err = await connection.query_info(
+				self.security_descriptor, err = await connection.query_info(
 					tree_id,
 					file_id,
 					info_type = QueryInfoType.SECURITY, 
@@ -163,7 +200,7 @@ class SMBFile:
 				if tree_id is not None and self.tree_id is None:
 					await connection.tree_disconnect(tree_id)
 
-		return self.sid, None
+		return self.security_descriptor, None
 
 	async def __read(self, size, offset):
 		"""
