@@ -161,7 +161,7 @@ class SMBAdminCheck:
 				except asyncio.CancelledError:
 					return
 				except Exception as e:
-					logger.exception('worker')
+					logger.debug('worker Error %s' % e)
 					continue
 
 		except asyncio.CancelledError:
